diff frontends/src/primitivus/contact_list.py @ 1139:75025461141f

move sat.tools.jid to sat_frontends.tools.jid
author souliane <souliane@mailoo.org>
date Tue, 26 Aug 2014 12:52:46 +0200
parents 0a9986452bba
children c0f15e52695a
line wrap: on
line diff
--- a/frontends/src/primitivus/contact_list.py	Tue Aug 26 09:54:23 2014 +0200
+++ b/frontends/src/primitivus/contact_list.py	Tue Aug 26 12:52:46 2014 +0200
@@ -22,7 +22,7 @@
 from urwid_satext import sat_widgets
 from sat_frontends.quick_frontend.quick_contact_list import QuickContactList
 from sat_frontends.quick_frontend.quick_utils import escapePrivate, unescapePrivate
-from sat.tools.jid import JID
+from sat_frontends.tools.jid import JID
 from sat_frontends.primitivus.status import StatusBar
 from sat_frontends.primitivus.constants import Const
 
@@ -79,7 +79,7 @@
 
     def setFocus(self, text, select=False):
         """give focus to the first element that matches the given text. You can also
         pass in text a sat.tools.jid.JID (it's a subclass of unicode).
         @param text: contact group name, contact or muc userhost, muc private dialog jid
         @param select: if True, the element is also clicked
         """
@@ -79,7 +79,7 @@
     def setFocus(self, text, select=False):
         """give focus to the first element that matches the given text. You can also
-        pass in text a sat.tools.jid.JID (it's a subclass of unicode).
+        pass in text a sat_frontends.tools.jid.JID (it's a subclass of unicode).
         @param text: contact group name, contact or muc userhost, muc private dialog jid
         @param select: if True, the element is also clicked